@@ -76,33 +76,12 @@ def _parse_analysis(data: Dict) -> Optional[Analysis]:
     return a
 
 
-def find_joint_calling_analysis(
-    analysis_project: str,
-    sample_ids: Collection[str],
-) -> Optional[Analysis]:
-    """
-    Query the DB to find the last completed joint-calling analysis for the samples
-    """
-    data = aapi.get_latest_complete_analysis_for_type(
-        project=analysis_project,
-        analysis_type='joint-calling',
-    )
-    a = _parse_analysis(data)
-    if not a:
-        return None
-    assert a.type == 'joint-calling', data
-    assert a.status == 'completed', data
-    if a.sample_ids != set(sample_ids):
-        return None
-    return a
-
-
 def find_analyses_by_sid(
     sample_ids: Collection[str],
     project: str,
     analysis_type: str,
     analysis_status: str = 'completed',
-    meta: Optional[Dict] = None,
+    only_staging: Optional[bool] = None,
 ) -> Dict[str, Analysis]:
     """
     Query the DB to find the last completed analysis for the type and samples,
@@ -110,18 +89,22 @@ def find_analyses_by_sid(
     sample (e.g. cram, gvcf)
     """
     analysis_per_sid: Dict[str, Analysis] = dict()
-
+    
     datas = aapi.query_analyses(
         AnalysisQueryModel(
             projects=[project],
             type=AnalysisType(analysis_type),
             status=AnalysisStatus(analysis_status),
             sample_ids=sample_ids,
-            meta=meta or {},
         )
     )
 
     for data in datas:
+        if only_staging is True and data['meta'].get('staging', False) is False:
+            continue
+        if only_staging is False and data['meta'].get('staging', False) is True:
+            continue
+
         a = _parse_analysis(data)
         if not a:
             continue
@@ -239,6 +222,7 @@ def replace_paths_to_test(s: Dict) -> Optional[Dict]:
 def find_inputs_from_db(
     input_projects: List[str],
     skip_samples: Optional[Collection[str]] = None,
+    only_samples: Optional[Collection[str]] = None,
     check_existence: bool = True,
     source_tag: Optional[str] = None,
     do_not_query_smdb_for_gvcfs: bool = False,
@@ -248,14 +232,14 @@ def find_inputs_from_db(
     sample-metadata server database.
 
     To specify a subset of GVCFs to search, set `source_tag`, which should
-    match the meta.source value analysis entries.
+    match the `meta.source` value analysis entries.
     """
     inputs = []
 
     for proj in input_projects:
         logger.info(f'Processing project {proj}')
         samples = sapi.get_samples(
-            body_get_samples_by_criteria_api_v1_sample_post={
+            body_get_samples={
                 'project_ids': [proj],
                 'active': True,
             }
@@ -265,6 +249,8 @@ def find_inputs_from_db(
             logger.info(f'No samples to process, skipping project {proj}')
             continue
 
+        if only_samples:
+            samples = [s for s in samples if s['id'] in only_samples]
         if skip_samples:
             logger.info('Checking which samples need to skip')
             not_skipped_sids = []
@@ -290,7 +276,6 @@ def find_inputs_from_db(
             sample_ids=[s['id'] for s in samples],
             analysis_type='qc',
             project=proj,
-            meta=dict(**meta),
         )
 
         reblocked_gvcf_by_sid: Dict[str, str] = {}
@@ -314,7 +299,7 @@ def find_inputs_from_db(
                 sample_ids=[s['id'] for s in samples],
                 analysis_type='gvcf',
                 project=proj,
-                meta=dict(staging=False, **meta),
+                only_staging=False,
             )
             staging_gvcf_analysis_per_sid = dict()
             if source_tag is not None:
@@ -322,7 +307,7 @@ def find_inputs_from_db(
                     sample_ids=[s['id'] for s in samples],
                     project=proj,
                     analysis_type='gvcf',
-                    meta=dict(staging=True, **meta),
+                    only_staging=True,
                 )
 
             sids_without_gvcf = []
@@ -431,6 +416,15 @@ def find_inputs_from_db(
                 
             stack = proj.replace('-test', '')
             project = s['meta'].get('project', proj.replace('-test', ''))
+            
+            qc_metrics = dict(
+                r_contamination=qc_metrics['FREEMIX'],
+                r_duplication=qc_metrics['percent_duplicates'] / 100.0,
+                insert_size_average=qc_metrics['insert_size_average'],
+                coverage_median=qc_metrics['MEDIAN_COVERAGE'],
+                r_30x=qc_metrics['PCT_30X'],
+                r_aligned_in_pairs=qc_metrics['percentage_of_properly_paired_reads_(%)'] / 100,
+            )
 
             entry = default_entry.copy()
             entry.update(
@@ -458,13 +452,13 @@ def find_inputs_from_db(
                     ),
                     'primary_study': seq_meta.get('Primary study', '-'),
                     # QC metrics:
-                    'r_contamination': qc_metrics.get('freemix'),
-                    'r_chimera': qc_metrics.get('pct_chimeras'),
-                    'r_duplication': qc_metrics.get('percent_duplication'),
-                    'median_insert_size': qc_metrics.get('median_insert_size'),
-                    'median_coverage': qc_metrics.get('median_coverage'),
-                    'r_30x': qc_metrics.get('pct_30x'),
-                    'r_aligned_in_pairs': qc_metrics.get('pct_reads_aligned_in_pairs'),
+                    'r_contamination': qc_metrics.get('r_contamination'),
+                    'r_chimera': qc_metrics.get('r_chimeras'),
+                    'r_duplication': qc_metrics.get('r_duplication'),
+                    'insert_size': qc_metrics.get('insert_size_average'),
+                    'coverage': qc_metrics.get('coverage_median'),
+                    'r_30x': qc_metrics.get('r_30x'),
+                    'r_aligned_in_pairs': qc_metrics.get('r_aligned_in_pairs'),
                     'continental_pop': s['meta'].get('continental_pop', '-'),
                     'subcontinental_pop': s['meta'].get('subcontinental_pop') or s['meta'].get('subpop', '-'),
                 }
@@ -509,7 +503,6 @@ def add_validation_samples(df: pd.DataFrame) -> pd.DataFrame:
                     'external_id': sn,
                     'fam_id': 'CEPH',
                     'sex': '1' if sn == 'NA12891' else '2',
-                    'sex_karyotype': 'XY' if sn == 'NA12891' else 'XX',
                     'pat_id': 'NA12891' if sn == 'NA12878' else '-',
                     'mat_id': 'NA12892' if sn == 'NA12878' else '-',
                     'project': 'giab',
