@@ -33,7 +33,7 @@ logger.setLevel(logging.INFO)
     required=True,
     help='path to a CSV with QC metadata for the samples in the input Matrix Table. '
     'The following columns are expected: '
-    's,freemix,pct_chimeras,duplication,median_insert_size. '
+    's,freemix,pct_chimeras,duplication,insert_size. '
     'Must be keyed by "s".',
 )
 @click.option(
@@ -59,12 +59,6 @@ logger.setLevel(logging.INFO)
     callback=utils.get_validation_callback(ext='ht', must_exist=False),
     required=True,
 )
-@click.option(
-    '--out-custom-qc-ht',
-    'out_custom_qc_ht_path',
-    callback=utils.get_validation_callback(ext='ht', must_exist=False),
-    required=True,
-)
 @click.option(
     '--tmp-bucket',
     'tmp_bucket',
@@ -97,7 +91,6 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
     out_hard_filtered_samples_ht_path: str,
     out_sex_ht_path: str,
     out_hail_sample_qc_ht_path: str,
-    out_custom_qc_ht_path: str,
     tmp_bucket: str,
     local_tmp_dir: str,
     overwrite: bool,
@@ -123,16 +116,6 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
         overwrite=overwrite,
     )
 
-    # Calculate separately the number of non-gnomAD SNPs
-    sqc.cpg_custom_metrics(
-        split_mt=mt_split,
-        tmp_bucket=tmp_bucket,
-        out_ht_path=out_custom_qc_ht_path,
-        overwrite=overwrite,
-        count_gnomad_snps=True,
-        count_chrx_het_hom=True,
-    )
-
     # `sex_ht` row fields: is_female, chr20_mean_dp, sex_karyotype
     sex_ht = sqc.infer_sex(
         mt=mt,
